Share Apache Arrow objects between Python and R using rpy2.

[![pypi](https://img.shields.io/pypi/v/rpy2-arrow.svg?style=flat-square)](https://pypi.python.org/pypi/rpy2-arrow)
![Python package](https://github.com/rpy2/rpy2-arrow/workflows/Python%20package/badge.svg)

This package supports sharing Apache Arrow data structures across Python and R by using
[rpy2](https://rpy2.github.io),
R's [arrow](https://arrow.apache.org/docs/r/index.html),
and Python's [pyarrow](https://arrow.apache.org/docs/python/index.html).

This is still work in progress. The [HTML doc](https://rpy2.github.io/rpy2-arrow/version/main/html/) should be up-to-date.

To install:

```bash
pip install rpy2-arrow
```
